# String format build errors are mostly avoided by gcc stupidity
# Only few are usually fixed by patches, it makes no sense.
# So disable check at all.
%define Werror_cflags %{nil}

%bcond_without cycles

Summary:	A fully functional 3D modeling/rendering/animation package
Name:		blender
Version:	2.76b
Release:	3
License:	GPLv2+
Group:		Graphics
Url:		http://www.blender.org/
Source0:	http://download.blender.org/source/%{name}-%{version}.tar.gz
Source100:	blender.rpmlintrc
Patch0:		blender-2.71-sse2.patch
Patch1:		blender-2.60-error-when-missing-sse.patch
Patch2:		blender-2.58-static-lib.patch
Patch3:		blender-2.65-openjpeg_stdbool.patch
Patch4:		blender-2.67-jack-libname.patch
# Cycles build fails with undefined reference error as libs are build as shared
Patch5:		blender-2.76-cycles-static.patch
# Patch submitted upstream - Blender Patches item #19234,
Patch6:		blender-2.67-uninit-var.patch
# From system clew package
Patch7:		blender-2.76b-clew-opencl.so.1.patch

BuildRequires:	cmake >= 2.8
BuildRequires:	boost-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	gomp-devel
BuildRequires:	jemalloc-devel
BuildRequires:	jpeg-devel
BuildRequires:	openjpeg-devel
BuildRequires:	opensubdiv-devel
BuildRequires:	tiff-devel
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xi)
%if %{with cycles}
BuildRequires:	OpenImageIO-devel
BuildRequires:	OpenColorIO-devel
%endif
Requires:	python3 >= 3.3

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%files
%doc release/text/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_iconsdir}/hicolor/*/apps/%{name}.*

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer.py %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

#----------------------------------------------------------------------------

%prep
%setup -q
%patch0 -p0 -b .sse2~
%patch1 -p0 -b .sse~
%patch2 -p0 -b .static~
%patch3 -p1 -b .openjpeg~
%patch4 -p0 -b .jack~
%patch5 -p1 -b .cycles-static~
%patch6 -p1
%patch7 -p1 -b .opencl~

%build
%ifarch %{ix86}
# build non-sse flavour
%cmake \
	-DWITH_INSTALL_PORTABLE:BOOL=OFF \
	-DWITH_GAMEENGINE:BOOL=ON \
	-DWITH_PLAYER:BOOL=ON \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{py3_ver} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_BUILTIN_GLEW:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_IMAGE_REDCODE:BOOL=ON \
	-DWITH_OPENSUBDIV:BOOL=ON \
	-DWITH_SYSTEM_OPENJPEG:BOOL=ON \
	-DOPENJPEG_ROOT_DIR=%{_includedir}/openjpeg-1.5 \
%if %{with cycles}
	-DWITH_CYCLES:BOOL=ON \
	-DWITH_OPENCOLORIO:BOOL=ON \
%else
	-DWITH_CYCLES:BOOL=OFF \
%endif
%ifarch %{ix86}
	-DSUPPORT_SSE2_BUILD=OFF \
	-DSUPPORT_SSE_BUILD=OFF \
%endif
	-DWITH_RAYOPTIMIZATION:BOOL=OFF
%make
cd ..
mv build non-sse
%endif

#build sse flavour
%cmake \
	-DWITH_INSTALL_PORTABLE:BOOL=OFF \
	-DWITH_GAMEENGINE:BOOL=ON \
	-DWITH_PLAYER:BOOL=ON \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{py3_ver} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_BUILTIN_GLEW:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_IMAGE_REDCODE:BOOL=ON \
	-DWITH_OPENSUBDIV:BOOL=ON \
	-DWITH_SYSTEM_OPENJPEG:BOOL=ON \
	-DOPENJPEG_ROOT_DIR=%{_includedir}/openjpeg-1.5 \
%if %{with cycles}
	-DWITH_CYCLES:BOOL=ON \
	-DWITH_OPENCOLORIO:BOOL=ON \
%else
	-DWITH_CYCLES:BOOL=OFF \
%endif
%ifarch %{ix86}
	-DSUPPORT_SSE2_BUILD=OFF \
%endif
	-DWITH_RAYOPTIMIZATION:BOOL=ON
%make

%install
#install sse flavour
pushd build
%makeinstall_std
popd

# Install hicolor icons.
for i in 16x16 22x22 32x32 48x48 256x256 ; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}/apps
  install -pm 0644 release/freedesktop/icons/${i}/apps/%{name}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -pm 0644 release/freedesktop/icons/scalable/apps/%{name}.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%ifarch %{ix86}
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.sse

#install non-sse flavour
rm -fr build
mv non-sse build
pushd build
%makeinstall_std
popd
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

sed -i -e 's,#!/usr/bin/python,#!/usr/bin/python3,' %{buildroot}%{_bindir}/blender-thumbnailer.py %{buildroot}%{_datadir}/%{name}/*/scripts/modules/blend_render_info.py


%changelog

* Mon Feb 15 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.76b-3
- (3f35a3f) Enable OpenSubdiv support via cmake option
- (Andrey Bondrov: f342ad5) Build with OpenSubdiv support
- (Andrey Bondrov: 859dd27) Add patch to fix libOpenCL.so.1 dlopen in clew library

* Sat Feb 06 2016 Denis Silakov <dsilakov@gmail.com> 2.76b-2
- (25ed73f) Rebuild with new OpenImageIO

* Mon Feb 01 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.76b-1
- (5515bd3) New version 2.76b

* Mon Feb 01 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.76-2
- (7b0e1f7) Add patch to fix dynamic loading of libjack

* Wed Oct 14 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.76-1
- (89f17e8) New version 2.76
- (89f17e8) Update build options
- (89f17e8) Add jemalloc-devel to BuildRequires

* Wed Apr 01 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.74-1
- (bdfea75) New version 2.74

* Tue Mar 17 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.73-2
- (94bd17a) Bump release

* Fri Jan 09 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.73-1
- (4a2011e) New version 2.73

* Thu Oct 02 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.72-1
- (7864506) New version 2.72
- (7864506) Make sure we don't build 32 bit version with SSE2 support because it's broken (build fails)

* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 2.70a-5
- (2f5aad9) MassBuild#440: Increase release tag

* Thu Jun 26 2014 Denis Silakov <denis.silakov@rosalab.ru> 2.70a-4
- (729e236) Add DPYTHON_VERSION
- (Andrey Bondrov: 7d1aa60) Bump release

* Thu Jun 19 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.70a-3
- (b8f8dac) Bump release

* Wed Jun 18 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.70a-2
- (d0a1b72) New version 2.70a, try not to use localedir patch

* Tue Jun 03 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.69-3
- (f17fab5) MassBuild#430: Increase release tag

* Tue Dec 17 2013 Alexander Kazancev <kazancas@gmail.com> 2.69-2
- (3362474) Rebuild with libglew

* Sun Nov 17 2013 RA <oeai@symbiants.com> 2.69-1
- (74b94bb) v 69 blender.spec

* Sun Nov 17 2013 RA <oeai@symbiants.com> 2.68a-1
- (d255977) v 69
- (Andrey Bondrov: db6be4a) LOG Update BuildRequires
- (Andrey Bondrov: 073ddcd) LOG New version 2.68a

* Wed Aug 14 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.67-3
- (ab96cd1) LOG Rebuild with new ffmpeg

* Thu Aug 01 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.67-2
- (94da64d) LOG Rebuild with new ffmpeg

* Mon May 13 2013 Denis Silakov <denis.silakov@rosalab.ru> 2.67-1
- (0608d3c) Added missing patch
- (Denis Silakov: 6440bb2) LOG Updated to 2.67

* Fri Mar 15 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.66a-1
- (4ef48a0) LOG New version 2.66a, merge cleanups with Cooker, re-diff some patches, disable string format security check as it's useless here

* Wed Feb 20 2013 root <root@localhost.localdomain> 2.65a-1
- (db90be3) update to 2.65a

* Sun Oct 07 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-3
- (d9fa16e) LOG Use better patch for system locales

* Sat Oct 06 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-2
- (87c0854) LOG Add patch to fix Cycles build, build with fftw3 support

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
- (8eafbd3) Drop old patch


